@@ -3,14 +3,8 @@ from typing import Optional, Union
 
 import abjad
 
-from ..utilities.enforce_time_signature import enforce_time_signature
-from ..utilities.remove_repeated_dynamics import remove_repeated_dynamics
-from ..utilities.remove_repeated_time_signatures import (
-    remove_repeated_time_signatures,
-)
-from ..utilities.reposition_dynamics import reposition_dynamics
-from ..utilities.reposition_slurs import reposition_slurs
-from ..utilities.time_signature_extractor import time_signature_extractor
+from ..utilities.inspect import inspect
+from ..utilities.mutate import mutate
 
 
 class Shuffler:
@@ -36,7 +30,7 @@ class Shuffler:
             e'4
         }
 
-        .. figure:: ../_images/image-Shuffler-1.png
+        .. figure:: ../_images/Shuffler-z2om98675v.png
 
         >>> notes = shuffler()
         >>> staff = abjad.Staff(notes)
@@ -50,7 +44,7 @@ class Shuffler:
             f'4
         }
 
-        .. figure:: ../_images/image-Shuffler-2.png
+        .. figure:: ../_images/Shuffler-xu7sln4vt7n.png
 
         To get the result of the last operation, use the property
         :attr:`current_window`.
@@ -67,7 +61,7 @@ class Shuffler:
             f'4
         }
 
-        .. figure:: ../_images/image-Shuffler-3.png
+        .. figure:: ../_images/Shuffler-gphtpqn9jb.png
 
         Calling the object outputs the same result as using the method
         :meth:`shuffle`.
@@ -84,9 +78,9 @@ class Shuffler:
             d'4
         }
 
-        .. figure:: ../_images/image-Shuffler-4.png
+        .. figure:: ../_images/Shuffler-g965k0d03if.png
 
-    ..  warning::
+    .. warning::
 
         Unlike the other classes in Auxjad, the very first call of an instance
         of this class will already process the initial container. To disable
@@ -110,7 +104,7 @@ class Shuffler:
             f'4
         }
 
-        .. figure:: ../_images/image-Shuffler-5.png
+        .. figure:: ../_images/Shuffler-76039tn5b9k.png
 
     :func:`len()`:
         Applying the :func:`len()` function to the shuffler will return the
@@ -152,7 +146,8 @@ class Shuffler:
         will be applied on the very first call.
 
         >>> container = abjad.Container(
-        ...     r"\time 3/4 c'4 d'4 e'4 \time 2/4 f'4 g'4")
+        ...     r"\time 3/4 c'4 d'4 e'4 \time 2/4 f'4 g'4"
+        ... )
         >>> shuffler = auxjad.Shuffler(container,
         ...                            pitch_only=False,
         ...                            preserve_rest_position=True,
@@ -230,7 +225,7 @@ class Shuffler:
             c'8.
         }
 
-        .. figure:: ../_images/image-Shuffler-6.png
+        .. figure:: ../_images/Shuffler-5j79m0wuxu.png
 
         Setting :attr:`pitch_only` to ``True`` enables pitch mode, so only
         pitches are shuffled (and not durations). Note how in the example below
@@ -254,7 +249,50 @@ class Shuffler:
             e'8.
         }
 
-        .. figure:: ../_images/image-Shuffler-7.png
+        .. figure:: ../_images/Shuffler-f9jbzqkrkdf.png
+
+    .. note::
+
+        Altering the value of :attr:`pitch_only`: will replace the original
+        :attr:`contents`: with the contents of :attr:`current_window`. Note how
+        in the example below, the shuffled leaves in measure 3 comes from the
+        previous measure and not from the initial :attr:`contents`:.
+
+        >>> container = abjad.Container(r"c'4.. d'16 e'4. f'8")
+        >>> shuffler = auxjad.Shuffler(container, pitch_only=True)
+        >>> notes = shuffler.shuffle_n(2)
+        >>> staff = abjad.Staff(notes)
+        >>> shuffler.pitch_only = False
+        >>> notes = shuffler.shuffle_n(2)
+        >>> staff.append(notes)
+        >>> auxjad.mutate(staff[:]).remove_repeated_time_signatures()
+        >>> abjad.f(staff)
+        \new Staff
+        {
+            \time 4/4
+            d'4..
+            c'16
+            f'4.
+            e'8
+            d'4..
+            f'16
+            c'4.
+            e'8
+            f'16
+            d'4..
+            e'8
+            c'4.
+            c'4.
+            d'8
+            ~
+            d'4
+            ~
+            d'16
+            e'8
+            f'16
+        }
+
+        .. figure:: ../_images/Shuffler-tyq8y6q8zr9.png
 
     :meth:`rotate`:
         Besides shuffling, logical ties and pitches can also be rotated using
@@ -263,7 +301,8 @@ class Shuffler:
         :attr:`pitch_only`.
 
         >>> container = abjad.Container(
-        ...     r"\time 3/4 c'16 d'8. ~ d'4 e'4 r4 f'4 ~ f'8.. g'32")
+        ...     r"\time 3/4 c'16 d'8. ~ d'4 e'4 r4 f'4 ~ f'8.. g'32"
+        ... )
         >>> shuffler = auxjad.Shuffler(container)
         >>> notes = shuffler.rotate()
         >>> staff = abjad.Staff(notes)
@@ -288,10 +327,11 @@ class Shuffler:
             c'16
         }
 
-        .. figure:: ../_images/image-Shuffler-8.png
+        .. figure:: ../_images/Shuffler-7vamgsxlr6.png
 
         >>> container = abjad.Container(
-        ...     r"\time 3/4 c'16 d'8. ~ d'4 e'4 r4 f'4 ~ f'8.. g'32")
+        ...     r"\time 3/4 c'16 d'8. ~ d'4 e'4 r4 f'4 ~ f'8.. g'32"
+        ... )
         >>> shuffler = auxjad.Shuffler(container, pitch_only=True)
         >>> notes = shuffler.rotate()
         >>> staff = abjad.Staff(notes)
@@ -311,7 +351,7 @@ class Shuffler:
             c'32
         }
 
-        .. figure:: ../_images/image-Shuffler-9.png
+        .. figure:: ../_images/Shuffler-89cx79bjji8.png
 
         This method can also take the optional parameters ``n_rotations`` and
         ``anticlockwise``. The first is an :obj:`int` setting the number of
@@ -319,7 +359,8 @@ class Shuffler:
         setting the direction of the rotation (default ``False``).
 
         >>> container = abjad.Container(
-        ...     r"\time 3/4 c'16 d'8. ~ d'4 e'4 r4 f'4 ~ f'8.. g'32")
+        ...     r"\time 3/4 c'16 d'8. ~ d'4 e'4 r4 f'4 ~ f'8.. g'32"
+        ... )
         >>> shuffler = auxjad.Shuffler(container, pitch_only=True)
         >>> notes = shuffler.rotate(n_rotations=2, anticlockwise=True)
         >>> staff = abjad.Staff(notes)
@@ -339,7 +380,7 @@ class Shuffler:
             r32
         }
 
-        .. figure:: ../_images/image-Shuffler-10.png
+        .. figure:: ../_images/Shuffler-g6v6wjm12ub.png
 
     :attr:`preserve_rest_position`:
         If :attr:`preserve_rest_position` is set to ``True``, the positions of
@@ -367,12 +408,12 @@ class Shuffler:
             e'8.
         }
 
-        .. figure:: ../_images/image-Shuffler-11.png
+        .. figure:: ../_images/Shuffler-pmou83f7rlj.png
 
         In logical ties mode, the rests will remain at the same index and will
         have the same total duration as before, but their position in the
         measure might vary since the duration of the pitched logical ties
-        preceeding it might change.
+        preceding it might change.
 
         >>> container = abjad.Container(r"c'8. d'4 r8 r8. e'16 f'8.")
         >>> shuffler = auxjad.Shuffler(container, preserve_rest_position=True)
@@ -392,7 +433,7 @@ class Shuffler:
             c'8.
         }
 
-        .. figure:: ../_images/image-Shuffler-12.png
+        .. figure:: ../_images/Shuffler-7hbp2kdpqof.png
 
     :attr:`disable_rewrite_meter`:
         If :attr:`disable_rewrite_meter` is set to ``True``, then the automatic
@@ -414,7 +455,7 @@ class Shuffler:
             d'8
         }
 
-        .. figure:: ../_images/image-Shuffler-13.png
+        .. figure:: ../_images/Shuffler-tb78izpzvjp.png
 
     :meth:`shuffle_n` and :meth:`rotate_n`:
         To output several shuffled containers at once, use the methods
@@ -441,14 +482,14 @@ class Shuffler:
             e'4.
             g'16
             f'8.
-            e'4.
-            c'8
+            e'4
             ~
-            c'8
+            e'8
+            c'4
             d'8
         }
 
-        .. figure:: ../_images/image-Shuffler-14.png
+        .. figure:: ../_images/Shuffler-vtia65lbk5.png
 
         >>> container = abjad.Container(r"c'4 d'8 e'4. f'8. g'16")
         >>> shuffler = auxjad.Shuffler(container)
@@ -468,13 +509,11 @@ class Shuffler:
             ~
             f'16
             g'16
-            c'8
-            ~
-            c'8
+            c'4
             d'8
         }
 
-        .. figure:: ../_images/image-Shuffler-15.png
+        .. figure:: ../_images/Shuffler-3dqhy8eoiez.png
 
     :attr:`omit_time_signatures`:
         To disable time signatures altogether, initialise this class with the
@@ -504,23 +543,24 @@ class Shuffler:
             c'16
         }
 
-        .. figure:: ../_images/image-Shuffler-16.png
+        .. figure:: ../_images/Shuffler-1v3lwhj430b.png
 
-    ..  tip::
+    .. tip::
 
         All methods that return an |abjad.Selection| will add an initial time
         signature to it. The :meth:`shuffle_n` and :meth:`rotate_n` methods
         automatically remove repeated time signatures. When joining selections
         output by multiple method calls, use
-        :func:`auxjad.remove_repeated_time_signatures()` on the whole container
-        after fusing the selections to remove any unecessary time signature
-        changes.
+        |auxjad.mutate().remove_repeated_time_signatures()| on the whole
+        container after fusing the selections to remove any unecessary time
+        signature changes.
 
     Time signature changes:
         This class handles time signature changes too:
 
         >>> container = abjad.Container(
-        ...     r"\time 3/4 c'8. d'4 r8 r8. \time 2/4 e'16 f'4..")
+        ...     r"\time 3/4 c'8. d'4 r8 r8. \time 2/4 e'16 f'4.."
+        ... )
         >>> shuffler = auxjad.Shuffler(container)
         >>> notes = shuffler.shuffle_n(2)
         >>> staff = abjad.Staff(notes)
@@ -551,14 +591,15 @@ class Shuffler:
             e'16
         }
 
-        .. figure:: ../_images/image-Shuffler-17.png
+        .. figure:: ../_images/Shuffler-yx11u6o14v.png
 
     Tuplet support:
         Tuplets are supported when :attr:`pitch_only` is ``True`` (pitch-only
         mode).
 
         >>> container = abjad.Container(
-        ...     r"\time 5/4 r4 \times 2/3 {c'4 d'2} e'4. f'8")
+        ...     r"\time 5/4 r4 \times 2/3 {c'4 d'2} e'4. f'8"
+        ... )
         >>> shuffler = auxjad.Shuffler(container, pitch_only=True)
         >>> notes = shuffler()
         >>> staff = abjad.Staff(notes)
@@ -575,16 +616,17 @@ class Shuffler:
             r8
         }
 
-        .. figure:: ../_images/image-Shuffler-18.png
+        .. figure:: ../_images/Shuffler-mjxubkel8y.png
 
-    ..  error::
+    .. error::
 
         Tuplets are not supported when :attr:`pitch_only` is ``False`` (logical
         tie mode). Using a container with tuplets and :attr:`pitch_only` set to
         ``True`` will raise a :exc:`TypeError` exception.
 
         >>> container = abjad.Container(
-        ...     r"\time 5/4 r4 \times 2/3 {c'4 d'2} e'4. f'8")
+        ...     r"\time 5/4 r4 \times 2/3 {c'4 d'2} e'4. f'8"
+        ... )
         >>> shuffler = auxjad.Shuffler(container)
         >>> notes = shuffler()
         TypeError: 'contents' contain one ore more tuplets, which are not
@@ -594,7 +636,8 @@ class Shuffler:
         This class can also handle dynamics and articulations.
 
         >>> container = abjad.Container(
-        ...     r"<c' e' g'>4--\p d'8-. e'8-. f'4-^\f r4")
+        ...     r"<c' e' g'>4--\p d'8-. e'8-. f'4-^\f r4"
+        ... )
         >>> shuffler = auxjad.Shuffler(container)
         >>> notes = shuffler.shuffle_n(3)
         >>> staff = abjad.Staff(notes)
@@ -622,11 +665,9 @@ class Shuffler:
             - \marcato
             ~
             f'8
-            <c' e' g'>8
+            <c' e' g'>4
             \p
             - \tenuto
-            ~
-            <c' e' g'>8
             e'8
             - \staccato
             f'4
@@ -644,15 +685,15 @@ class Shuffler:
             r4
         }
 
-        .. figure:: ../_images/image-Shuffler-19.png
+        .. figure:: ../_images/Shuffler-2ibui58pj8w.png
 
     .. tip::
 
-        The functions :func:`auxjad.remove_repeated_dynamics()` and
-        :func:`auxjad.reposition_clefs()` can be used to clean the output and
-        remove repeated dynamics and unnecessary clef changes.
+        The functions |auxjad.mutate().remove_repeated_dynamics()| and
+        |auxjad.mutate().reposition_clefs()| can be used to clean the output
+        and remove repeated dynamics and unnecessary clef changes.
 
-    ..  warning::
+    .. warning::
 
         Do note that some elements that span multiple notes (such as ottava
         indicators, manual beams, etc.) can become problematic when notes
@@ -680,7 +721,7 @@ class Shuffler:
             f'4
         }
 
-        .. figure:: ../_images/image-Shuffler-20.png
+        .. figure:: ../_images/Shuffler-qsee7chymo.png
 
         >>> shuffler()
         >>> abjad.f(shuffler.contents)
@@ -691,7 +732,7 @@ class Shuffler:
             f'4
         }
 
-        .. figure:: ../_images/image-Shuffler-21.png
+        .. figure:: ../_images/Shuffler-ii3fxe001ki.png
 
         >>> shuffler.contents = abjad.Container(r"cs2 ds2")
         >>> abjad.f(shuffler.contents)
@@ -700,7 +741,7 @@ class Shuffler:
             ds2
         }
 
-        .. figure:: ../_images/image-Shuffler-22.png
+        .. figure:: ../_images/Shuffler-p2vd4mfvucp.png
 
     Tweaking |abjad.mutate().rewrite_meter()|:
         This function uses the default logical tie splitting algorithm from
@@ -719,7 +760,7 @@ class Shuffler:
             d'8
         }
 
-        .. figure:: ../_images/image-Shuffler-23.png
+        .. figure:: ../_images/Shuffler-t4lsqxg18ab.png
 
         Set :attr:`boundary_depth` to a different number to change its
         behaviour.
@@ -740,13 +781,20 @@ class Shuffler:
             d'8
         }
 
-        .. figure:: ../_images/image-Shuffler-24.png
+        .. figure:: ../_images/Shuffler-7na5znnhhwe.png
 
         Other arguments available for tweaking the output of
         |abjad.mutate().rewrite_meter()| are :attr:`maximum_dot_count` and
         :attr:`rewrite_tuplets`, which work exactly as the identically named
         arguments of |abjad.mutate().rewrite_meter()|.
 
+        This class also accepts the arguments ``fuse_across_groups_of_beats``,
+        ``fuse_quadruple_meter``, ``fuse_triple_meter``, and
+        ``extract_trivial_tuplets``, which are passed on to
+        |auxjad.mutate().prettify_rewrite_meter()| (the latter can be disabled
+        by setting ``prettify_rewrite_meter`` to ``False``). See the
+        documentation of this function for more details on these arguments.
+
     :attr:`disable_rewrite_meter`:
         By default, this class uses the |abjad.mutate().rewrite_meter()|
         mutation.
@@ -769,12 +817,30 @@ class Shuffler:
             d'8
         }
 
-        .. figure:: ../_images/image-Shuffler-25.png
+        .. figure:: ../_images/Shuffler-7cfnxx7shci.png
 
         Set :attr:`disable_rewrite_meter` to ``True`` in order to disable this
         behaviour.
 
-        >>> container = abjad.Container(r"c'4 d'8 e'8 f'2")
+        >>> container = abjad.Container(r"c'4 d'8. e'16 f'2")
+        >>> abjad.f(container)
+        \new Staff
+        {
+            \time 4/4
+            e'16
+            f'8.
+            ~
+            f'4
+            ~
+            f'16
+            c'8.
+            ~
+            c'16
+            d'8.
+        }
+
+        .. figure:: ../_images/Shuffler-6gm4ev48j9k.png
+
         >>> shuffler = auxjad.Shuffler(container,
         ...                            disable_rewrite_meter=True,
         ...                            )
@@ -784,20 +850,20 @@ class Shuffler:
         \new Staff
         {
             \time 4/4
-            e'8
+            e'16
             f'2
             c'4
-            d'8
+            d'8.
         }
 
-        .. figure:: ../_images/image-Shuffler-26.png
+        .. figure:: ../_images/Shuffler-xlr4x3bhj6n.png
 
     Using as iterator:
         The instances of this class can also be used as an iterator, which can
         then be used in a for loop. Note that unlike the methods
         :meth:`shuffle_n` and :meth:`rotate_n`, time signatures are added to
         each window returned by the shuffler. Use the function
-        :func:`auxjad.remove_repeated_time_signatures()` to clean the output
+        |auxjad.mutate().remove_repeated_time_signatures()| to clean the output
         when using this class in this way. It is also important to note that a
         ``break`` statement is needed when using this class as an iterator. The
         reason is that shuffling is a process that can happen indefinitely
@@ -810,7 +876,7 @@ class Shuffler:
         ...     staff.append(window)
         ...     if abjad.inspect(staff).duration() == abjad.Duration((9, 4)):
         ...         break
-        >>> auxjad.remove_repeated_time_signatures(staff)
+        >>> auxjad.mutate(staff[:]).remove_repeated_time_signatures()
         >>> abjad.f(staff)
         \new Staff
         {
@@ -826,7 +892,7 @@ class Shuffler:
             d'4
         }
 
-        .. figure:: ../_images/image-Shuffler-27.png
+        .. figure:: ../_images/Shuffler-3gyz7atvemx.png
     """
 
     ### CLASS VARIABLES ###
@@ -846,6 +912,11 @@ class Shuffler:
                  '_maximum_dot_count',
                  '_rewrite_tuplets',
                  '_process_on_first_call',
+                 '_prettify_rewrite_meter',
+                 '_extract_trivial_tuplets',
+                 '_fuse_across_groups_of_beats',
+                 '_fuse_quadruple_meter',
+                 '_fuse_triple_meter',
                  )
 
     ### INITIALISER ###
@@ -861,6 +932,11 @@ class Shuffler:
                  maximum_dot_count: Optional[int] = None,
                  rewrite_tuplets: bool = True,
                  process_on_first_call: bool = True,
+                 prettify_rewrite_meter: bool = True,
+                 extract_trivial_tuplets: bool = True,
+                 fuse_across_groups_of_beats: bool = True,
+                 fuse_quadruple_meter: bool = True,
+                 fuse_triple_meter: bool = True,
                  ):
         r'Initialises self.'
         self.contents = contents
@@ -871,6 +947,11 @@ class Shuffler:
         self.boundary_depth = boundary_depth
         self.maximum_dot_count = maximum_dot_count
         self.rewrite_tuplets = rewrite_tuplets
+        self.prettify_rewrite_meter = prettify_rewrite_meter
+        self.extract_trivial_tuplets = extract_trivial_tuplets
+        self.fuse_across_groups_of_beats = fuse_across_groups_of_beats
+        self.fuse_quadruple_meter = fuse_quadruple_meter
+        self.fuse_triple_meter = fuse_triple_meter
         self.process_on_first_call = process_on_first_call
         self._is_first_window = True
 
@@ -959,8 +1040,8 @@ class Shuffler:
         dummy_container = abjad.Container()
         for _ in range(n):
             dummy_container.append(self.__call__())
-        remove_repeated_time_signatures(dummy_container)
-        remove_repeated_dynamics(dummy_container)
+        mutate(dummy_container[:]).remove_repeated_time_signatures()
+        mutate(dummy_container[:]).remove_repeated_dynamics()
         output = dummy_container[:]
         dummy_container[:] = []
         return output
@@ -982,8 +1063,8 @@ class Shuffler:
         for _ in range(n):
             dummy_container.append(self.rotate(n_rotations=n_rotations,
                                                anticlockwise=anticlockwise))
-        remove_repeated_time_signatures(dummy_container)
-        remove_repeated_dynamics(dummy_container)
+        mutate(dummy_container[:]).remove_repeated_time_signatures()
+        mutate(dummy_container[:]).remove_repeated_dynamics()
         output = dummy_container[:]
         dummy_container[:] = []
         return output
@@ -992,7 +1073,9 @@ class Shuffler:
 
     def _update_logical_selections(self):
         r'Updates the selection of logical ties of :attr:`contents`.'
-        self._logical_selections = self._get_logical_selections(self._contents)
+        self._logical_selections = self._get_logical_selections(
+            self._contents
+        )
         self._logical_selections_indeces = list(range(self.__len__()))
 
     def _get_pitch_list(self) -> list:
@@ -1008,7 +1091,7 @@ class Shuffler:
                 self._pitches.append(leaf.written_pitches)
 
     def _shuffle_list_preserving_rests(self,
-                                       input_list: list
+                                       input_list: list,
                                        ) -> list:
         r'Shuffles a :obj:`list` while keeping rest indeces unchanged.'
         dummy_list = [input_list[i] for i in range(len(input_list))
@@ -1052,7 +1135,8 @@ class Shuffler:
             random.shuffle(self._logical_selections_indeces)
         else:
             self._shuffle_list_preserving_rests(
-                self._logical_selections_indeces)
+                self._logical_selections_indeces
+            )
         self._rewrite_logical_selections()
         return self.current_window
 
@@ -1113,7 +1197,8 @@ class Shuffler:
         # writing dummy_container in shuffled order
         dummy_container = abjad.Container()
         logical_selections = self._get_logical_selections(
-            abjad.mutate(self._contents).copy())
+            abjad.mutate(self._contents).copy()
+        )
         self._force_dynamics(logical_selections)
         for index in self._logical_selections_indeces:
             logical_selection = logical_selections[index]
@@ -1124,24 +1209,26 @@ class Shuffler:
             cyclic=True,
         )
         # attaching time signature structure
-        enforce_time_signature(dummy_container,
-                               self._time_signatures,
-                               disable_rewrite_meter=True,
-                               )
+        mutate(dummy_container).enforce_time_signature(
+            self._time_signatures,
+            disable_rewrite_meter=True,
+        )
         # handling dynamics and slurs
-        reposition_dynamics(dummy_container)
-        reposition_slurs(dummy_container)
+        mutate(dummy_container[:]).reposition_dynamics()
+        mutate(dummy_container[:]).reposition_slurs()
         # rewrite meter
         if not self._disable_rewrite_meter:
-            measures = abjad.select(dummy_container[:]).group_by_measure()
-            for measure, time_signature in zip(measures,
-                                               self._time_signatures):
-                abjad.mutate(measure).rewrite_meter(
-                    time_signature,
-                    boundary_depth=self._boundary_depth,
-                    maximum_dot_count=self._maximum_dot_count,
-                    rewrite_tuplets=self._rewrite_tuplets,
-                )
+            mutate(dummy_container).auto_rewrite_meter(
+                meter_list=self._time_signatures,
+                boundary_depth=self._boundary_depth,
+                maximum_dot_count=self._maximum_dot_count,
+                rewrite_tuplets=self._rewrite_tuplets,
+                prettify_rewrite_meter=self._prettify_rewrite_meter,
+                extract_trivial_tuplets=self._extract_trivial_tuplets,
+                fuse_across_groups_of_beats=self._fuse_across_groups_of_beats,
+                fuse_quadruple_meter=self._fuse_quadruple_meter,
+                fuse_triple_meter=self._fuse_triple_meter,
+            )
         # output
         self._is_first_window = False
         self._current_window = dummy_container[:]
@@ -1150,7 +1237,7 @@ class Shuffler:
     def _rewrite_pitches(self):
         r'Rewrites the pitches of the current window.'
         dummy_container = abjad.Container(
-            abjad.mutate(self._current_window[:]).copy()
+            abjad.mutate(self._contents[:]).copy()
         )
         leaf_counter = 0
         for pitch, logical_selection in zip(self._pitches,
@@ -1181,15 +1268,15 @@ class Shuffler:
                 abjad.mutate(selection).replace(new_leaf)
                 leaf_counter += 1
         # attaching time signature structure
-        enforce_time_signature(dummy_container,
-                               self._time_signatures,
-                               disable_rewrite_meter=True,
-                               )
+        mutate(dummy_container[:]).extract_trivial_tuplets()
+        mutate(dummy_container).enforce_time_signature(
+            self._time_signatures,
+            disable_rewrite_meter=True,
+        )
         # output
         self._is_first_window = False
         self._current_window = dummy_container[:]
         dummy_container[:] = []
-        self._update_logical_selections()  # new logical selections
 
     @staticmethod
     def _get_logical_selections(container):
@@ -1264,9 +1351,10 @@ class Shuffler:
         dummy_container[:] = []
         self._update_logical_selections()
         self._get_pitch_list()
-        self._time_signatures = time_signature_extractor(self._contents,
-                                                         do_not_use_none=True,
-                                                         )
+        inspector = inspect(self._contents)
+        self._time_signatures = inspector.time_signature_extractor(
+            do_not_use_none=True,
+        )
         self._is_first_window = True
 
     @property
@@ -1283,6 +1371,13 @@ class Shuffler:
         if not isinstance(pitch_only, bool):
             raise TypeError("'pitch_only' must be 'bool'")
         self._pitch_only = pitch_only
+        # potentially new logical selections when shifting from pitch-only mode
+        # to logical selections mode
+        self._update_logical_selections()
+        self._get_pitch_list()
+        self._contents = abjad.Container(
+            abjad.mutate(self._current_window).copy()
+        )
 
     @property
     def preserve_rest_position(self) -> bool:
@@ -1374,6 +1469,81 @@ class Shuffler:
             raise TypeError("'rewrite_tuplets' must be 'bool'")
         self._rewrite_tuplets = rewrite_tuplets
 
+    @property
+    def prettify_rewrite_meter(self) -> bool:
+        r"""Used to enable or disable the mutation
+        |auxjad.mutate().prettify_rewrite_meter()| (default ``True``).
+        """
+        return self._prettify_rewrite_meter
+
+    @prettify_rewrite_meter.setter
+    def prettify_rewrite_meter(self,
+                               prettify_rewrite_meter: bool,
+                               ):
+        if not isinstance(prettify_rewrite_meter, bool):
+            raise TypeError("'prettify_rewrite_meter' must be 'bool'")
+        self._prettify_rewrite_meter = prettify_rewrite_meter
+
+    @property
+    def extract_trivial_tuplets(self) -> bool:
+        r"""Sets the argument ``extract_trivial_tuplets`` of
+        |auxjad.mutate().prettify_rewrite_meter()|.
+        """
+        return self._extract_trivial_tuplets
+
+    @extract_trivial_tuplets.setter
+    def extract_trivial_tuplets(self,
+                                extract_trivial_tuplets: bool,
+                                ):
+        if not isinstance(extract_trivial_tuplets, bool):
+            raise TypeError("'extract_trivial_tuplets' must be 'bool'")
+        self._extract_trivial_tuplets = extract_trivial_tuplets
+
+    @property
+    def fuse_across_groups_of_beats(self) -> bool:
+        r"""Sets the argument ``fuse_across_groups_of_beats`` of
+        |auxjad.mutate().prettify_rewrite_meter()|.
+        """
+        return self._fuse_across_groups_of_beats
+
+    @fuse_across_groups_of_beats.setter
+    def fuse_across_groups_of_beats(self,
+                                    fuse_across_groups_of_beats: bool,
+                                    ):
+        if not isinstance(fuse_across_groups_of_beats, bool):
+            raise TypeError("'fuse_across_groups_of_beats' must be 'bool'")
+        self._fuse_across_groups_of_beats = fuse_across_groups_of_beats
+
+    @property
+    def fuse_quadruple_meter(self) -> bool:
+        r"""Sets the argument ``fuse_quadruple_meter`` of
+        |auxjad.mutate().prettify_rewrite_meter()|.
+        """
+        return self._fuse_quadruple_meter
+
+    @fuse_quadruple_meter.setter
+    def fuse_quadruple_meter(self,
+                             fuse_quadruple_meter: bool,
+                             ):
+        if not isinstance(fuse_quadruple_meter, bool):
+            raise TypeError("'fuse_quadruple_meter' must be 'bool'")
+        self._fuse_quadruple_meter = fuse_quadruple_meter
+
+    @property
+    def fuse_triple_meter(self) -> bool:
+        r"""Sets the argument ``fuse_triple_meter`` of
+        |auxjad.mutate().prettify_rewrite_meter()|.
+        """
+        return self._fuse_triple_meter
+
+    @fuse_triple_meter.setter
+    def fuse_triple_meter(self,
+                          fuse_triple_meter: bool,
+                          ):
+        if not isinstance(fuse_triple_meter, bool):
+            raise TypeError("'fuse_triple_meter' must be 'bool'")
+        self._fuse_triple_meter = fuse_triple_meter
+
     @property
     def process_on_first_call(self) -> bool:
         r"""If ``True`` then :attr:`contents` will be processed in the very
